<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="53"/>
        <location filename="../mainwindow.cpp" line="263"/>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>MX Cleanup</source>
        <translation>MX Oprydning</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>Clean Folders</source>
        <translation>Ryd op i mapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="566"/>
        <source>Delete Logs</source>
        <translation>Slet logge</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="617"/>
        <source>Old logs</source>
        <translation>Gamle logge</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="591"/>
        <source>All logs</source>
        <translation>Alle logge</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <location filename="../mainwindow.ui" line="411"/>
        <location filename="../mainwindow.ui" line="604"/>
        <source>Don&apos;t empty</source>
        <translation>Tøm ikke</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="119"/>
        <source>Display help </source>
        <translation>Vis hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>About this application</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="200"/>
        <source>Quit application</source>
        <translation>Afslut programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Apply</source>
        <translation>Anvend</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Empty Trash</source>
        <translation>Tøm papirkurv</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>Selected user</source>
        <translation>Valgte bruger</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>All users</source>
        <translation>Alle brugere</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Trash older than:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <location filename="../mainwindow.ui" line="630"/>
        <source> days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="376"/>
        <source>Clear APT Cache</source>
        <translation>Ryd APT-mellemlager</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>Old files</source>
        <translation>Gamle filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="404"/>
        <source>All files</source>
        <translation>Alle filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Free Disk Space for User</source>
        <translation>Frigør diskplads for bruger</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="452"/>
        <location filename="../mainwindow.ui" line="465"/>
        <source>Select user to repair</source>
        <translation>Vælg bruger til reparation</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="468"/>
        <source>Select user:</source>
        <translation>Vælg bruger:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Grafisk værktøj til at analysere diskforbrug</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="490"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Kør diskforbrugsanalysering</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <source>Schedule</source>
        <translation>Planlæg</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>No automatic clean</source>
        <translation>Ingen automatisk oprydning</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Daily</source>
        <translation>Dagligt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>Weekly</source>
        <translation>Ugenligt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="537"/>
        <source>Monthly</source>
        <translation>Månedligt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="646"/>
        <source>Logs older than:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Done</source>
        <translation>Færdig</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="255"/>
        <source>Cleanup command done</source>
        <translation>Oprydningskommando færdig</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MiB blev frigivet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="264"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>Quick and safe removal of old files</source>
        <translation>Hurtig og sikker fjernelse af gamle filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Ophavsret (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>Changelog</source>
        <translation>Ændringslog</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="270"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="291"/>
        <source>&amp;Close</source>
        <translation>&amp;Luk</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>You must run this program as root.</source>
        <translation>Du skal køre programmet som root.</translation>
    </message>
</context>
</TS>
